slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDSetProblemType

Specifies the type of the singular value problem.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDSetProblemType(SVD svd,SVDProblemType type)

Logically Collective on svd

### Input Parameters

| svd | - the singular value solver context
| type | - a known type of singular value problem

### Options Database Keys

| -svd_standard | - standard singular value decomposition (SVD)
| -svd_generalized | - generalized singular value problem (GSVD)
| -svd_hyperbolic | - hyperbolic singular value problem (HSVD)

### Notes

The GSVD requires that two matrices have been passed via SVDSetOperators(). The HSVD requires that a signature matrix has been passed via SVDSetSignature().

### See Also

SVDSetOperators(), SVDSetSignature(), SVDSetType(), SVDGetProblemType(), SVDProblemType

### Level

intermediate

### Location

src/svd/interface/svdopts.c

### Examples

src/svd/tutorials/ex15.c.html
src/svd/tutorials/ex15f.F.html
src/svd/tutorials/ex45.c.html
src/svd/tutorials/ex48.c.html
src/svd/tutorials/ex51.c.html
src/svd/tutorials/ex52.c.html
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages